# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class UserAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'signed_up_at': 'str',
        'to_be_retained': 'bool',
        'profile': 'Profile',
        'metadata': 'object',
        'identities': 'list[Identity]'
    }

    attribute_map = {
        'signed_up_at': 'signedUpAt',
        'to_be_retained': 'toBeRetained',
        'profile': 'profile',
        'metadata': 'metadata',
        'identities': 'identities'
    }

    nulls = set()

    def __init__(self, signed_up_at=None, to_be_retained=None, profile=None, metadata=None, identities=None, local_vars_configuration=None):  # noqa: E501
        """UserAllOf - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._signed_up_at = None
        self._to_be_retained = None
        self._profile = None
        self._metadata = None
        self._identities = None
        self.discriminator = None

        if signed_up_at is not None:
            self.signed_up_at = signed_up_at
        if to_be_retained is not None:
            self.to_be_retained = to_be_retained
        if profile is not None:
            self.profile = profile
        if metadata is not None:
            self.metadata = metadata
        if identities is not None:
            self.identities = identities

    @property
    def signed_up_at(self):
        """Gets the signed_up_at of this UserAllOf.  # noqa: E501


        :return: The signed_up_at of this UserAllOf.  # noqa: E501
        :rtype: str
        """
        return self._signed_up_at

    @signed_up_at.setter
    def signed_up_at(self, signed_up_at):
        """Sets the signed_up_at of this UserAllOf.


        :param signed_up_at: The signed_up_at of this UserAllOf.  # noqa: E501
        :type: str
        """

        self._signed_up_at = signed_up_at

    @property
    def to_be_retained(self):
        """Gets the to_be_retained of this UserAllOf.  # noqa: E501


        :return: The to_be_retained of this UserAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._to_be_retained

    @to_be_retained.setter
    def to_be_retained(self, to_be_retained):
        """Sets the to_be_retained of this UserAllOf.


        :param to_be_retained: The to_be_retained of this UserAllOf.  # noqa: E501
        :type: bool
        """

        self._to_be_retained = to_be_retained

    @property
    def profile(self):
        """Gets the profile of this UserAllOf.  # noqa: E501


        :return: The profile of this UserAllOf.  # noqa: E501
        :rtype: Profile
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """Sets the profile of this UserAllOf.


        :param profile: The profile of this UserAllOf.  # noqa: E501
        :type: Profile
        """

        self._profile = profile

    @property
    def metadata(self):
        """Gets the metadata of this UserAllOf.  # noqa: E501


        :return: The metadata of this UserAllOf.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this UserAllOf.


        :param metadata: The metadata of this UserAllOf.  # noqa: E501
        :type: object
        """

        self._metadata = metadata

    @property
    def identities(self):
        """Gets the identities of this UserAllOf.  # noqa: E501

        The user's connected identities.  # noqa: E501

        :return: The identities of this UserAllOf.  # noqa: E501
        :rtype: list[Identity]
        """
        return self._identities

    @identities.setter
    def identities(self, identities):
        """Sets the identities of this UserAllOf.

        The user's connected identities.  # noqa: E501

        :param identities: The identities of this UserAllOf.  # noqa: E501
        :type: list[Identity]
        """

        self._identities = identities

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserAllOf):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class ParticipantLeaveBody(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'user_external_id': 'str',
        'participant_id': 'str'
    }

    attribute_map = {
        'user_id': 'userId',
        'user_external_id': 'userExternalId',
        'participant_id': 'participantId'
    }

    nulls = set()

    def __init__(self, user_id=None, user_external_id=None, participant_id=None, local_vars_configuration=None):  # noqa: E501
        """ParticipantLeaveBody - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._user_external_id = None
        self._participant_id = None
        self.discriminator = None

        if user_id is not None:
            self.user_id = user_id
        if user_external_id is not None:
            self.user_external_id = user_external_id
        if participant_id is not None:
            self.participant_id = participant_id

    @property
    def user_id(self):
        """Gets the user_id of this ParticipantLeaveBody.  # noqa: E501

        The id of the user that will be removed from the conversation. It will return 404 if the user can’t be found.   # noqa: E501

        :return: The user_id of this ParticipantLeaveBody.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ParticipantLeaveBody.

        The id of the user that will be removed from the conversation. It will return 404 if the user can’t be found.   # noqa: E501

        :param user_id: The user_id of this ParticipantLeaveBody.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_external_id(self):
        """Gets the user_external_id of this ParticipantLeaveBody.  # noqa: E501

        The externalId of the user that will be removed from the conversation. It will return 404 if the user can’t be found.   # noqa: E501

        :return: The user_external_id of this ParticipantLeaveBody.  # noqa: E501
        :rtype: str
        """
        return self._user_external_id

    @user_external_id.setter
    def user_external_id(self, user_external_id):
        """Sets the user_external_id of this ParticipantLeaveBody.

        The externalId of the user that will be removed from the conversation. It will return 404 if the user can’t be found.   # noqa: E501

        :param user_external_id: The user_external_id of this ParticipantLeaveBody.  # noqa: E501
        :type: str
        """

        self._user_external_id = user_external_id

    @property
    def participant_id(self):
        """Gets the participant_id of this ParticipantLeaveBody.  # noqa: E501

        The participantId of the user that will be removed from the conversation. It will return 404 if the user can’t be found.   # noqa: E501

        :return: The participant_id of this ParticipantLeaveBody.  # noqa: E501
        :rtype: str
        """
        return self._participant_id

    @participant_id.setter
    def participant_id(self, participant_id):
        """Sets the participant_id of this ParticipantLeaveBody.

        The participantId of the user that will be removed from the conversation. It will return 404 if the user can’t be found.   # noqa: E501

        :param participant_id: The participant_id of this ParticipantLeaveBody.  # noqa: E501
        :type: str
        """

        self._participant_id = participant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ParticipantLeaveBody):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ParticipantLeaveBody):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class DownloadMessageRefBodyAllOfAppleInteractiveDataRef(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'url': 'str',
        'bid': 'str',
        'key': 'str',
        'signature': 'str',
        'owner': 'str'
    }

    attribute_map = {
        'url': 'url',
        'bid': 'bid',
        'key': 'key',
        'signature': 'signature',
        'owner': 'owner'
    }

    nulls = set()

    def __init__(self, url=None, bid=None, key=None, signature=None, owner=None, local_vars_configuration=None):  # noqa: E501
        """DownloadMessageRefBodyAllOfAppleInteractiveDataRef - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._url = None
        self._bid = None
        self._key = None
        self._signature = None
        self._owner = None
        self.discriminator = None

        self.url = url
        self.bid = bid
        self.key = key
        self.signature = signature
        self.owner = owner

    @property
    def url(self):
        """Gets the url of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501


        :return: The url of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.


        :param url: The url of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def bid(self):
        """Gets the bid of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501


        :return: The bid of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501
        :rtype: str
        """
        return self._bid

    @bid.setter
    def bid(self, bid):
        """Sets the bid of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.


        :param bid: The bid of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and bid is None:  # noqa: E501
            raise ValueError("Invalid value for `bid`, must not be `None`")  # noqa: E501

        self._bid = bid

    @property
    def key(self):
        """Gets the key of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501


        :return: The key of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.


        :param key: The key of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and key is None:  # noqa: E501
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501

        self._key = key

    @property
    def signature(self):
        """Gets the signature of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501


        :return: The signature of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """Sets the signature of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.


        :param signature: The signature of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and signature is None:  # noqa: E501
            raise ValueError("Invalid value for `signature`, must not be `None`")  # noqa: E501

        self._signature = signature

    @property
    def owner(self):
        """Gets the owner of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501


        :return: The owner of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.


        :param owner: The owner of this DownloadMessageRefBodyAllOfAppleInteractiveDataRef.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and owner is None:  # noqa: E501
            raise ValueError("Invalid value for `owner`, must not be `None`")  # noqa: E501

        self._owner = owner

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DownloadMessageRefBodyAllOfAppleInteractiveDataRef):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DownloadMessageRefBodyAllOfAppleInteractiveDataRef):
            return True

        return self.to_dict() != other.to_dict()
